@@ -58,10 +58,9 @@ defaults = {
     "shop-id-thread-count": 300,
     "shopify-api-key": unset,
     "shopify-api-secret": unset,
-    "shopify-api-version": "2019-04",
-    "shopify-app-api-key": unset,
-    "shopify-app-api-secret": unset,
-    "shopify-app-api-version": "2019-04",
+    "shopify-api-version": "2020-10",
+    "shopify-api-throttle-limit": 1,
+    "shopify-api-throttle-period": 3000,
     "shopify-app-name": "The name of this app",
     "shopify-app-description": "The description of this app",
     "shopify-app-author": "The author of this app",
